@@ -28,20 +28,19 @@
 
 struct _MetaWaylandPointerGrabInterface
 {
-  void (*focus) (MetaWaylandPointerGrab * grab,
-                 MetaWaylandSurface * surface, wl_fixed_t x, wl_fixed_t y);
-  void (*motion) (MetaWaylandPointerGrab * grab,
-                  uint32_t time, wl_fixed_t x, wl_fixed_t y);
-  void (*button) (MetaWaylandPointerGrab * grab,
-                  uint32_t time, uint32_t button, uint32_t state);
+  void (*focus) (MetaWaylandPointerGrab *grab,
+                 MetaWaylandSurface     *surface,
+		 const ClutterEvent     *event);
+  void (*motion) (MetaWaylandPointerGrab *grab,
+		  const ClutterEvent     *event);
+  void (*button) (MetaWaylandPointerGrab *grab,
+		  const ClutterEvent     *event);
 };
 
 struct _MetaWaylandPointerGrab
 {
   const MetaWaylandPointerGrabInterface *interface;
   MetaWaylandPointer *pointer;
-  MetaWaylandSurface *focus;
-  wl_fixed_t x, y;
 };
 
 struct _MetaWaylandPointer
@@ -51,16 +50,17 @@ struct _MetaWaylandPointer
   struct wl_resource *focus_resource;
   struct wl_listener focus_listener;
   guint32 focus_serial;
-  struct wl_signal focus_signal;
+  guint32 click_serial;
 
   MetaWaylandPointerGrab *grab;
   MetaWaylandPointerGrab default_grab;
   wl_fixed_t grab_x, grab_y;
+  wl_fixed_t focus_x, focus_y;
   guint32 grab_button;
   guint32 grab_serial;
   guint32 grab_time;
 
-  wl_fixed_t x, y;
+  wl_fixed_t x, y; /* TODO: remove, use ClutterInputDevice instead */
   MetaWaylandSurface *current;
   struct wl_listener current_listener;
   wl_fixed_t current_x, current_y;
@@ -69,17 +69,15 @@ struct _MetaWaylandPointer
 };
 
 void
-meta_wayland_pointer_init (MetaWaylandPointer *pointer);
+meta_wayland_pointer_init (MetaWaylandPointer *pointer,
+			   gboolean            is_native);
 
 void
 meta_wayland_pointer_release (MetaWaylandPointer *pointer);
 
 void
 meta_wayland_pointer_set_focus (MetaWaylandPointer *pointer,
-                                MetaWaylandSurface *surface,
-                                wl_fixed_t sx,
-                                wl_fixed_t sy);
-
+                                MetaWaylandSurface *surface);
 void
 meta_wayland_pointer_destroy_focus (MetaWaylandPointer *pointer);
 
@@ -95,8 +93,18 @@ meta_wayland_pointer_begin_modal (MetaWaylandPointer *pointer);
 void
 meta_wayland_pointer_end_modal   (MetaWaylandPointer *pointer);
 
+gboolean
+meta_wayland_pointer_start_popup_grab (MetaWaylandPointer *pointer,
+				       MetaWaylandSurface *popup);
+
 void
 meta_wayland_pointer_set_current (MetaWaylandPointer *pointer,
                                   MetaWaylandSurface *surface);
 
+void
+meta_wayland_pointer_get_relative_coordinates (MetaWaylandPointer *pointer,
+					       MetaWaylandSurface *surface,
+					       wl_fixed_t         *x,
+					       wl_fixed_t         *y);
+
 #endif /* __META_WAYLAND_POINTER_H__ */
