@@ -32,6 +32,7 @@
 #include <meta/meta-cursor-tracker.h>
 
 #include "meta-wayland-types.h"
+#include "meta-wayland-versions.h"
 #include "meta-wayland-surface.h"
 #include "meta-wayland-seat.h"
 
@@ -61,6 +62,7 @@ typedef struct
 struct _MetaWaylandCompositor
 {
   struct wl_display *wayland_display;
+  char *display_name;
   struct wl_event_loop *wayland_loop;
   GMainLoop *init_loop;
   ClutterActor *stage;
@@ -104,6 +106,7 @@ void                    meta_wayland_compositor_set_input_focus (MetaWaylandComp
                                                                  MetaWindow            *window);
 
 MetaLauncher           *meta_wayland_compositor_get_launcher    (MetaWaylandCompositor *compositor);
+gboolean                meta_wayland_compositor_is_native       (MetaWaylandCompositor *compositor);
 
 MetaWaylandBuffer *     meta_wayland_buffer_from_resource       (struct wl_resource *resource);
 
